==> qtjambi-designer-5.15.7-sources.jar: io/qt/designer/QDesignerFormWindowToolInterface.java <==
package io.qt.designer;


/**
 * <p>Java wrapper for Qt class QDesignerFormWindowToolInterface</p>
 */
public abstract class QDesignerFormWindowToolInterface extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QDesignerFormWindowToolInterface.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QDesignerFormWindowToolInterface {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.widgets.QAction action(){
            return action_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.widgets.QAction action_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public void activated(){
            activated_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native void activated_native(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.designer.QDesignerFormEditorInterface core(){
            return core_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.designer.QDesignerFormEditorInterface core_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public void deactivated(){
            deactivated_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native void deactivated_native(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.widgets.QWidget editor(){
            return editor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.widgets.QWidget editor_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.designer.QDesignerFormWindowInterface formWindow(){
            return formWindow_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.designer.QDesignerFormWindowInterface formWindow_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public boolean handleEvent(io.qt.widgets.QWidget widget, io.qt.widgets.QWidget managedWidget, io.qt.core.QEvent event){
            return handleEvent_native_QWidget_ptr_QWidget_ptr_QEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(widget), QtJambi_LibraryUtilities.internal.checkedNativeId(managedWidget), QtJambi_LibraryUtilities.internal.checkedNativeId(event));
        }
        @io.qt.QtUninvokable
        private native boolean handleEvent_native_QWidget_ptr_QWidget_ptr_QEvent_ptr(long __this__nativeId, long widget, long managedWidget, long event);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QDesignerFormWindowToolInterface(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QDesignerFormWindowToolInterface() {
        this((io.qt.core.QObject)null);
    }
    
    public QDesignerFormWindowToolInterface(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QDesignerFormWindowToolInterface instance, io.qt.core.QObject parent);
    
    @io.qt.QtUninvokable
    public abstract io.qt.widgets.QAction action();
    
    @io.qt.QtUninvokable
    private native io.qt.widgets.QAction action_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public abstract void activated();
    
    @io.qt.QtUninvokable
    private native void activated_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public abstract io.qt.designer.QDesignerFormEditorInterface core();
    
    @io.qt.QtUninvokable
    private native io.qt.designer.QDesignerFormEditorInterface core_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public abstract void deactivated();
    
    @io.qt.QtUninvokable
    private native void deactivated_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public abstract io.qt.widgets.QWidget editor();
    
    @io.qt.QtUninvokable
    private native io.qt.widgets.QWidget editor_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public abstract io.qt.designer.QDesignerFormWindowInterface formWindow();
    
    @io.qt.QtUninvokable
    private native io.qt.designer.QDesignerFormWindowInterface formWindow_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public abstract boolean handleEvent(io.qt.widgets.QWidget widget, io.qt.widgets.QWidget managedWidget, io.qt.core.QEvent event);
    
    @io.qt.QtUninvokable
    private native boolean handleEvent_native_QWidget_ptr_QWidget_ptr_QEvent_ptr(long __this__nativeId, long widget, long managedWidget, long event);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDesignerFormWindowToolInterface(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QDesignerFormWindowToolInterface(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QDesignerFormWindowToolInterface instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-designer-6.2-sources.jar: io/qt/designer/QDesignerFormWindowToolInterface.java <==
package io.qt.designer;


/**
 * <p>Java wrapper for Qt class QDesignerFormWindowToolInterface</p>
 */
public abstract class QDesignerFormWindowToolInterface extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QDesignerFormWindowToolInterface.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QDesignerFormWindowToolInterface {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.gui.QAction action(){
            return action_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.gui.QAction action_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public void activated(){
            activated_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native void activated_native(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.designer.QDesignerFormEditorInterface core(){
            return core_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.designer.QDesignerFormEditorInterface core_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public void deactivated(){
            deactivated_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native void deactivated_native(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.widgets.QWidget editor(){
            return editor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.widgets.QWidget editor_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.designer.QDesignerFormWindowInterface formWindow(){
            return formWindow_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.designer.QDesignerFormWindowInterface formWindow_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public boolean handleEvent(io.qt.widgets.QWidget widget, io.qt.widgets.QWidget managedWidget, io.qt.core.QEvent event){
            return handleEvent_native_QWidget_ptr_QWidget_ptr_QEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(widget), QtJambi_LibraryUtilities.internal.checkedNativeId(managedWidget), QtJambi_LibraryUtilities.internal.checkedNativeId(event));
        }
        @io.qt.QtUninvokable
        private native boolean handleEvent_native_QWidget_ptr_QWidget_ptr_QEvent_ptr(long __this__nativeId, long widget, long managedWidget, long event);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QDesignerFormWindowToolInterface(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QDesignerFormWindowToolInterface() {
        this((io.qt.core.QObject)null);
    }
    
    public QDesignerFormWindowToolInterface(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QDesignerFormWindowToolInterface instance, io.qt.core.QObject parent);
    
    @io.qt.QtUninvokable
    public abstract io.qt.gui.QAction action();
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QAction action_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public abstract void activated();
    
    @io.qt.QtUninvokable
    private native void activated_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public abstract io.qt.designer.QDesignerFormEditorInterface core();
    
    @io.qt.QtUninvokable
    private native io.qt.designer.QDesignerFormEditorInterface core_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public abstract void deactivated();
    
    @io.qt.QtUninvokable
    private native void deactivated_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public abstract io.qt.widgets.QWidget editor();
    
    @io.qt.QtUninvokable
    private native io.qt.widgets.QWidget editor_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public abstract io.qt.designer.QDesignerFormWindowInterface formWindow();
    
    @io.qt.QtUninvokable
    private native io.qt.designer.QDesignerFormWindowInterface formWindow_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public abstract boolean handleEvent(io.qt.widgets.QWidget widget, io.qt.widgets.QWidget managedWidget, io.qt.core.QEvent event);
    
    @io.qt.QtUninvokable
    private native boolean handleEvent_native_QWidget_ptr_QWidget_ptr_QEvent_ptr(long __this__nativeId, long widget, long managedWidget, long event);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDesignerFormWindowToolInterface(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QDesignerFormWindowToolInterface(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QDesignerFormWindowToolInterface instance, QDeclarativeConstructor constructor);
    
}
